==> haskell-silently-1.2.5.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-silently.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 silently
version:              1.2.5.1
visibility:           public
id:                   silently-1.2.5.1-1Cr6sEo1LQi7sWIqP9r0hJ
key:                  silently-1.2.5.1-1Cr6sEo1LQi7sWIqP9r0hJ
license:              BSD-3-Clause
copyright:            (c) Trystan Spangler 2011
maintainer:
    Sönke Hahn <soenkehahn@gmail.com>, Simon Hengel <sol@typeful.net>

author:               Trystan Spangler
homepage:             https://github.com/hspec/silently
package-url:          https://github.com/hspec/silently
synopsis:             Prevent or capture writing to stdout and other handles.
description:          Prevent or capture writing to stdout and other handles.
category:             System, Testing
abi:                  d3f3a908829f90672c148839dc086f09
exposed:              True
exposed-modules:      System.IO.Silently
import-dirs:          /usr/lib/ghc-8.8.1/site-local/silently-1.2.5.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/silently-1.2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/silently-1.2.5.1
hs-libraries:         HSsilently-1.2.5.1-1Cr6sEo1LQi7sWIqP9r0hJ
depends:              base-4.13.0.0 deepseq-1.4.4.0 directory-1.3.3.2
haddock-interfaces:   /usr/share/doc/haskell-silently/html/silently.haddock
haddock-html:         /usr/share/doc/haskell-silently/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-silently-1.2.5.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-silently.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 silently
version:              1.2.5.1
visibility:           public
id:                   silently-1.2.5.1-DJKQExolDUD5tRw4m8syOR
key:                  silently-1.2.5.1-DJKQExolDUD5tRw4m8syOR
license:              BSD-3-Clause
copyright:            (c) Trystan Spangler 2011
maintainer:
    Sönke Hahn <soenkehahn@gmail.com>, Simon Hengel <sol@typeful.net>

author:               Trystan Spangler
homepage:             https://github.com/hspec/silently
package-url:          https://github.com/hspec/silently
synopsis:             Prevent or capture writing to stdout and other handles.
description:          Prevent or capture writing to stdout and other handles.
category:             System, Testing
abi:                  292e17d60e8a39fb2de8c417288b960b
exposed:              True
exposed-modules:      System.IO.Silently
import-dirs:          /usr/lib/ghc-8.8.2/site-local/silently-1.2.5.1
library-dirs:         /usr/lib/ghc-8.8.2/site-local/silently-1.2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/silently-1.2.5.1
hs-libraries:         HSsilently-1.2.5.1-DJKQExolDUD5tRw4m8syOR
depends:              base-4.13.0.0 deepseq-1.4.4.0 directory-1.3.4.0
haddock-interfaces:   /usr/share/doc/haskell-silently/html/silently.haddock
haddock-html:         /usr/share/doc/haskell-silently/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
